=== modified file 'NEWS'
--- NEWS	2009-03-12 13:43:15 +0000
+++ NEWS	2009-03-12 14:02:53 +0000
@@ -233,6 +233,9 @@
       updated to comply with this. The code already complied with the other
       criteria, but now it is enforced. (Marius Kruger)
 
+    ``bzrlib.branch.PushResult`` was renamed to 
+    ``bzrlib.branch.BranchPushResult``. (Jelmer Vernooij)
+
     * ``Branch.fetch`` and ``Repository.fetch`` now return None rather
       than a count of copied revisions and failed revisions. A while back
       we stopped ever reporting failed revisions because we started

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2009-03-12 06:24:39 +0000
+++ bzrlib/branch.py	2009-03-12 14:04:43 +0000
@@ -1383,7 +1383,7 @@
             "branch is opened.", (1, 8), None))
         self.create_hook(HookPoint('post_push',
             "Called after a push operation completes. post_push is called "
-            "with a bzrlib.branch.PushResult object and only runs in the "
+            "with a bzrlib.branch.BranchPushResult object and only runs in the "
             "bzr client.", (0, 15), None))
         self.create_hook(HookPoint('post_pull',
             "Called after a pull operation completes. post_pull is called "
@@ -2112,7 +2112,7 @@
 
         Must be called with self read locked and target write locked.
         """
-        result = PushResult()
+        result = BranchPushResult()
         result.source_branch = self
         result.target_branch = target
         result.old_revno, result.old_revid = target.last_revision_info()
@@ -2637,7 +2637,7 @@
         self._show_tag_conficts(to_file)
 
 
-class PushResult(_Result):
+class BranchPushResult(_Result):
     """Result of a Branch.push operation.
 
     :ivar old_revno: Revision number (eg 10) of the target before push.

=== modified file 'bzrlib/push.py'
--- bzrlib/push.py	2009-03-03 08:21:42 +0000
+++ bzrlib/push.py	2009-03-12 14:02:53 +0000
@@ -21,6 +21,29 @@
 from bzrlib.trace import note, warning
 
 
+class PushResult(object):
+    """Result of a push operation.
+
+    :ivar branch_push_result: Result of a push between branches
+    :ivar stacked_on: URL of the branch on which the result is stacked
+    """
+
+    def __init__(self):
+        self.branch_push_result = None
+        self.stacked_on = None
+
+    def report(self, to_file):
+        """Write a human-readable description of the result."""
+        if self.branch_push_result is None:
+            if self.stacked_on is not None:
+                note('Created new stacked branch referring to %s.' %
+                    self.stacked_on)
+            else:
+                note('Created new branch.')
+        else:
+            self.branch_push_result.report(to_file)
+
+
 def _show_push_branch(br_from, revision_id, location, to_file, verbose=False,
     overwrite=False, remember=False, stacked_on=None, create_prefix=False,
     use_existing_dir=False):
@@ -63,7 +86,7 @@
             # Found a branch, so we must have found a repository
             repository_to = br_to.repository
 
-    push_result = None
+    push_result = PushResult()
     if dir_to is None:
         # The destination doesn't exist; create it.
         # XXX: Refactor the create_prefix/no_create_prefix code into a
@@ -105,16 +128,11 @@
             revision_id=revision_id, stacked_on=stacked_on)
         # TODO: Some more useful message about what was copied
         try:
-            finally_stacked_on = br_to.get_stacked_on_url()
+            push_result.stacked_on = br_to.get_stacked_on_url()
         except (errors.UnstackableBranchFormat,
                 errors.UnstackableRepositoryFormat,
                 errors.NotStacked):
-            finally_stacked_on = None
-        if finally_stacked_on is not None:
-            note('Created new stacked branch referring to %s.' %
-                 finally_stacked_on)
-        else:
-            note('Created new branch.')
+            push_result.stacked_on = None
         # We successfully created the target, remember it
         if br_from.get_push_location() is None or remember:
             br_from.set_push_location(br_to.base)
@@ -134,7 +152,6 @@
                     "already exists at the destination location.")
         repository_to.fetch(br_from.repository, revision_id=revision_id)
         br_to = br_from.clone(dir_to, revision_id=revision_id)
-        note('Created new branch.')
         if br_from.get_push_location() is None or remember:
             br_from.set_push_location(br_to.base)
     else: # We have a valid to branch
@@ -150,28 +167,28 @@
                 tree_to = dir_to.open_workingtree()
             except errors.NotLocalUrl:
                 note("This transport does not update the working "
-                     "tree of: %s. See 'bzr help working-trees' for "
-                     "more information." % br_to.base)
-                push_result = br_from.push(br_to, overwrite,
-                                           stop_revision=revision_id)
+                        "tree of: %s. See 'bzr help working-trees' for "
+                        "more information." % br_to.base)
+                push_result.branch_push_result = br_from.push(br_to, overwrite,
+                                                   stop_revision=revision_id)
             except errors.NoWorkingTree:
-                push_result = br_from.push(br_to, overwrite,
-                                           stop_revision=revision_id)
+                push_result.branch_push_result = br_from.push(br_to, overwrite,
+                                                   stop_revision=revision_id)
             else:
                 tree_to.lock_write()
                 try:
-                    push_result = br_from.push(tree_to.branch, overwrite,
-                                               stop_revision=revision_id)
+                    push_result.branch_push_result = br_from.push(tree_to.branch,
+                        overwrite, stop_revision=revision_id)
                     tree_to.update()
                 finally:
                     tree_to.unlock()
         except errors.DivergedBranches:
             raise errors.BzrCommandError('These branches have diverged.'
                                     '  Try using "merge" and then "push".')
-    if push_result is not None:
-        push_result.report(to_file)
-        old_revid = push_result.old_revid
-        old_revno = push_result.old_revno
+    push_result.report(to_file)
+    if push_result.branch_push_result is not None:
+        old_revid = push_result.branch_push_result.old_revid
+        old_revno = push_result.branch_push_result.old_revno
     else:
         old_revid = _mod_revision.NULL_REVISION
         old_revno = 0

